@@ -53,6 +53,7 @@ def _flag_to_bool(spec):
 @click.option('-u', '--db-url', envvar='SQLCSV_DB_URL', required=True)
 @click.option('-p', '--pre-sql', default=None)
 @click.option('-P', '--post-sql', default=None)
+@click.option('-X', '--transaction', is_flag=True)
 @click.option('-H', '--no-header', is_flag=True)
 @click.option('-T', '--tab', is_flag=True)
 @click.option('-d', '--delimiter', default=',')
@@ -60,17 +61,18 @@ def _flag_to_bool(spec):
 @click.option('-Q', '--quoting', type=click.Choice(QUOTING.keys(), case_sensitive=False), default='MINIMAL')  # noqa
 @click.option('-q', '--quotechar', default='"')
 @click.option('-e', '--escapechar', default=None)
-@click.option('-b', '--doublequote', is_flag=True)
+@click.option('-B', '--no-doublequote', is_flag=True)
 @click.pass_context
 def cli(
-    ctx, db_url, pre_sql, post_sql,
+    ctx, db_url, pre_sql, post_sql, transaction,
     no_header, tab, delimiter, lineterminator,
-    quoting, quotechar, escapechar, doublequote,
+    quoting, quotechar, escapechar, no_doublequote,
 ):
     ctx.obj = Command(
         db_url=db_url,
         pre_sql=pre_sql,
         post_sql=post_sql,
+        transaction=transaction,
         header=not no_header,
         dialect=dict(
             delimiter='\t' if tab else delimiter,
@@ -78,7 +80,7 @@ def cli(
             quoting=QUOTING[quoting.upper()],
             quotechar=quotechar,
             escapechar=escapechar,
-            doublequote=doublequote,
+            doublequote=not no_doublequote,
         )
     )
 
@@ -101,11 +103,12 @@ def select(ctx, sql, sqlfile, outfile):
 @click.option('-i', '--infile', type=click.File('r'), default=sys.stdin)
 @click.option('-t', '--types', type=str, required=True)
 @click.option('-n', '--nullables', type=str, default=None)
+@click.option('-c', '--chunk-size', type=int, default=None)
 @click.pass_context
-def insert(ctx, sql, sqlfile, infile, types, nullables):
+def insert(ctx, sql, sqlfile, infile, types, nullables, chunk_size):
     command = ctx.obj
     sql = _get_sql(sql, sqlfile)
     types = tuple(map(_flag_to_type, types.split(',')))
     nullables = nullables and tuple(map(_flag_to_bool, nullables.split(',')))
 
-    command.insert(sql, infile, types, nullables)
+    command.insert(sql, infile, types, nullables, chunk_size)
