@@ -1,17 +1,30 @@
 import csv
 from contextlib import contextmanager
+from itertools import islice
 
 from sqlalchemy import create_engine
 
 from .casting import TypeCaster
 
 
+def chunker(iterable, size):
+    if size <= 0:
+        raise ValueError('Chunk size must be greater than 0')
+
+    it = iter(iterable)
+    chunk = tuple(islice(it, size))
+    while chunk:
+        yield chunk
+        chunk = tuple(islice(it, size))
+
+
 class Command:
 
-    def __init__(self, db_url, pre_sql, post_sql, header, dialect):
+    def __init__(self, db_url, pre_sql, post_sql, transaction, header, dialect):
         self._db_url = db_url
         self._pre_sql = pre_sql
         self._post_sql = post_sql
+        self._transaction = transaction
         self._header = header
         self._dialect = dialect
 
@@ -19,7 +32,7 @@ class Command:
     def _connect_exec(self):
         engine = create_engine(self._db_url)
 
-        with engine.connect() as conn:
+        with engine.begin() if self._transaction else engine.connect() as conn:
             if self._pre_sql:
                 conn.execute(self._pre_sql)
 
@@ -40,7 +53,7 @@ class Command:
             for row in result:
                 writer.writerow(row)
 
-    def insert(self, sql, infile, types, nullables):
+    def insert(self, sql, infile, types, nullables, chunk_size):
         reader = csv.reader(infile, **self._dialect)
         caster = TypeCaster(types, nullables)
 
@@ -48,4 +61,8 @@ class Command:
             if self._header:
                 next(reader)
 
-            conn.execute(sql, *(caster.cast(row) for row in reader))
+            if chunk_size is not None:
+                for chunk in chunker(reader, chunk_size):
+                    conn.execute(sql, *map(caster.cast, chunk))
+            else:
+                conn.execute(sql, *map(caster.cast, reader))
